aboutsummaryrefslogtreecommitdiffstats
path: root/spec/setupBrowser.js
diff options
context:
space:
mode:
Diffstat (limited to 'spec/setupBrowser.js')
-rw-r--r--spec/setupBrowser.js4
1 files changed, 3 insertions, 1 deletions
diff --git a/spec/setupBrowser.js b/spec/setupBrowser.js
index fb68b07..b2441c1 100644
--- a/spec/setupBrowser.js
+++ b/spec/setupBrowser.js
@@ -1,6 +1,8 @@
/* globals beforeEach, afterEach */
import { buildCanvas, clear } from './helpers.js'
+jasmine.DEFAULT_TIMEOUT_INTERVAL = 200
+
beforeEach(() => {
// buildFixtures()
buildCanvas()
@@ -1,6 +1,8 @@
-/* globals beforeEach, afterEach */
+/* globals beforeEach, afterEach, jasmine */
import { buildCanvas, clear } from './helpers.js'